@@ -1,23 +1,24 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
+from io import BytesIO
 from textwrap import dedent
 import unittest
-import mock
-from mock import patch
-from six import BytesIO
+from unittest import mock
+from unittest.mock import patch
 
 from diff_cover.violationsreporters import base
 
 from diff_cover.command_runner import CommandError
 from diff_cover.violationsreporters.base import QualityReporter
 from diff_cover.violationsreporters.java_violations_reporter import (
-    Violation, checkstyle_driver,
-    CheckstyleXmlDriver, FindbugsXmlDriver, PmdXmlDriver)
+    Violation,
+    checkstyle_driver,
+    CheckstyleXmlDriver,
+    FindbugsXmlDriver,
+    PmdXmlDriver,
+)
 
 
 def _patch_so_all_files_exist():
-    _mock_exists = patch.object(base.os.path, 'exists').start()
+    _mock_exists = patch.object(base.os.path, "exists").start()
     _mock_exists.returnvalue = True
 
 
@@ -25,7 +26,7 @@ def _setup_patch(return_value, status_code=0):
     mocked_process = mock.Mock()
     mocked_process.returncode = status_code
     mocked_process.communicate.return_value = return_value
-    mocked_subprocess = mock.patch('diff_cover.command_runner.subprocess').start()
+    mocked_subprocess = mock.patch("diff_cover.command_runner.subprocess").start()
     mocked_subprocess.Popen.return_value = mocked_process
     return mocked_process
 
@@ -42,13 +43,13 @@ class CheckstyleQualityReporterTest(unittest.TestCase):
         """Expect that we get no results."""
         quality = QualityReporter(checkstyle_driver)
 
-        result = quality.violations('')
+        result = quality.violations("")
         self.assertEqual(result, [])
 
     def test_no_java_file(self):
         """Expect that we get no results because no Python files."""
         quality = QualityReporter(checkstyle_driver)
-        file_paths = ['file1.coffee', 'subdir/file2.js']
+        file_paths = ["file1.coffee", "subdir/file2.js"]
         for path in file_paths:
             result = quality.violations(path)
             self.assertEqual(result, [])
@@ -56,15 +57,22 @@ class CheckstyleQualityReporterTest(unittest.TestCase):
     def test_quality(self):
         """Integration test."""
         # Patch the output of `checkstyle`
-        _setup_patch((
-            dedent("""
+        _setup_patch(
+            (
+                dedent(
+                    """
             [WARN] ../new_file.java:1:1: Line contains a tab character.
             [WARN] ../new_file.java:13: 'if' construct must use '{}'s.
-            """).strip().encode('ascii'), ''
-        ))
+            """
+                )
+                .strip()
+                .encode("ascii"),
+                "",
+            )
+        )
 
         expected_violations = [
-            Violation(1, 'Line contains a tab character.'),
+            Violation(1, "Line contains a tab character."),
             Violation(13, "'if' construct must use '{}'s."),
         ]
 
@@ -72,27 +80,28 @@ class CheckstyleQualityReporterTest(unittest.TestCase):
         quality = QualityReporter(checkstyle_driver)
 
         # Expect that the name is set
-        self.assertEqual(quality.name(), 'checkstyle')
+        self.assertEqual(quality.name(), "checkstyle")
 
         # Measured_lines is undefined for a
         # quality reporter since all lines are measured
-        self.assertIsNone(quality.measured_lines('../new_file.java'))
+        self.assertIsNone(quality.measured_lines("../new_file.java"))
 
         # Expect that we get violations for file1.java only
         # We're not guaranteed that the violations are returned
         # in any particular order.
-        actual_violations = quality.violations('../new_file.java')
+        actual_violations = quality.violations("../new_file.java")
         self.assertEqual(len(actual_violations), len(expected_violations))
         for expected in expected_violations:
             self.assertIn(expected, actual_violations)
 
 
 class CheckstyleXmlQualityReporterTest(unittest.TestCase):
-
     def setUp(self):
         _patch_so_all_files_exist()
         # Paths generated by git_path are always the given argument
-        _git_path_mock = patch('diff_cover.violationsreporters.java_violations_reporter.GitPathTool').start()
+        _git_path_mock = patch(
+            "diff_cover.violationsreporters.java_violations_reporter.GitPathTool"
+        ).start()
         _git_path_mock.relative_path = lambda path: path
         _git_path_mock.absolute_path = lambda path: path
 
@@ -106,12 +115,12 @@ class CheckstyleXmlQualityReporterTest(unittest.TestCase):
         quality = QualityReporter(CheckstyleXmlDriver())
 
         # Expect that we get no results
-        result = quality.violations('')
+        result = quality.violations("")
         self.assertEqual(result, [])
 
     def test_no_java_file(self):
         quality = QualityReporter(CheckstyleXmlDriver())
-        file_paths = ['file1.coffee', 'subdir/file2.js']
+        file_paths = ["file1.coffee", "subdir/file2.js"]
         # Expect that we get no results because no Java files
         for path in file_paths:
             result = quality.violations(path)
@@ -119,8 +128,10 @@ class CheckstyleXmlQualityReporterTest(unittest.TestCase):
 
     def test_quality(self):
         # Patch the output of `checkstyle`
-        _setup_patch((
-            dedent("""
+        _setup_patch(
+            (
+                dedent(
+                    """
             <?xml version="1.0" encoding="UTF-8"?>
             <checkstyle version="8.0">
                 <file name="file1.java">
@@ -136,63 +147,82 @@ class CheckstyleXmlQualityReporterTest(unittest.TestCase):
                     <error line="100" severity="error" message="Access to a protected member"/>
                 </file>
             </checkstyle>
-            """).strip().encode('ascii'), ''
-        ))
+            """
+                )
+                .strip()
+                .encode("ascii"),
+                "",
+            )
+        )
 
         expected_violations = [
-            Violation(1, 'error: Missing docstring'),
+            Violation(1, "error: Missing docstring"),
             Violation(2, "error: Unused variable 'd'"),
             Violation(2, "warning: TODO: Not the real way we'll store usages!"),
             Violation(579, "error: Unable to import 'rooted_paths'"),
-            Violation(150, "error: error while code parsing ([Errno 2] No such file or directory)"),
+            Violation(
+                150,
+                "error: error while code parsing ([Errno 2] No such file or directory)",
+            ),
             Violation(149, "error: Comma not followed by a space"),
-            Violation(113, "error: Unused argument 'cls'")
+            Violation(113, "error: Unused argument 'cls'"),
         ]
 
         # Parse the report
         quality = QualityReporter(CheckstyleXmlDriver())
 
         # Expect that the name is set
-        self.assertEqual(quality.name(), 'checkstyle')
+        self.assertEqual(quality.name(), "checkstyle")
 
         # Measured_lines is undefined for a
         # quality reporter since all lines are measured
-        self.assertIsNone(quality.measured_lines('file1.java'))
+        self.assertIsNone(quality.measured_lines("file1.java"))
 
         # Expect that we get violations for file1.java only
         # We're not guaranteed that the violations are returned
         # in any particular order.
-        actual_violations = quality.violations('file1.java')
+        actual_violations = quality.violations("file1.java")
         self.assertEqual(len(actual_violations), len(expected_violations))
         for expected in expected_violations:
             self.assertIn(expected, actual_violations)
 
     def test_quality_error(self):
         # Patch the output stderr/stdout and returncode of `checkstyle`
-        _setup_patch((
-            dedent("""
+        _setup_patch(
+            (
+                dedent(
+                    """
             <?xml version="1.0" encoding="UTF-8"?>
             <checkstyle version="8.0">
                 <file name="file1.java">
                     <error line="1" severity="error" message="Missing docstring"/>
                 </file>
             </checkstyle>
-            """), b'oops'), status_code=1)
+            """
+                ),
+                b"oops",
+            ),
+            status_code=1,
+        )
 
         # Parse the report
-        with patch('diff_cover.violationsreporters.java_violations_reporter.run_command_for_code') as code:
+        with patch(
+            "diff_cover.violationsreporters.java_violations_reporter.run_command_for_code"
+        ) as code:
             code.return_value = 0
             quality = QualityReporter(CheckstyleXmlDriver())
 
             # Expect an error
-            self.assertRaises(CommandError, quality.violations, 'file1.java')
+            self.assertRaises(CommandError, quality.violations, "file1.java")
 
     def test_quality_pregenerated_report(self):
 
         # When the user provides us with a pre-generated checkstyle report
         # then use that instead of calling checkstyle directly.
         checkstyle_reports = [
-            BytesIO(dedent("""
+            BytesIO(
+                dedent(
+                    """
                 <?xml version="1.0" encoding="UTF-8"?>
                 <checkstyle version="8.0">
                     <file name="path/to/file.java">
@@ -205,9 +235,14 @@ class CheckstyleXmlQualityReporterTest(unittest.TestCase):
                         <error line="259" severity="error" message="Invalid name '' for type variable (should match [a-z_][a-z0-9_]{2,30}$)"/>
                     </file>
                 </checkstyle>
-            """).strip().encode('utf-8')),
-
-            BytesIO(dedent("""
+            """
+                )
+                .strip()
+                .encode("utf-8")
+            ),
+            BytesIO(
+                dedent(
+                    """
             <?xml version="1.0" encoding="UTF-8"?>
             <checkstyle version="8.0">
                 <file name="path/to/file.java">
@@ -217,7 +252,11 @@ class CheckstyleXmlQualityReporterTest(unittest.TestCase):
                     <error line="183" severity="error" message="Missing docstring"/>
                 </file>
             </checkstyle>
-            """).strip().encode('utf-8'))
+            """
+                )
+                .strip()
+                .encode("utf-8")
+            ),
         ]
 
         # Generate the violation report
@@ -225,25 +264,31 @@ class CheckstyleXmlQualityReporterTest(unittest.TestCase):
 
         # Expect that we get the right violations
         expected_violations = [
-            Violation(1, 'error: Missing docstring'),
-            Violation(57, 'warning: TODO the name of this method is a little bit confusing'),
-            Violation(183, "error: Invalid name '' for type argument (should match [a-z_][a-z0-9_]{2,30}$)")
+            Violation(1, "error: Missing docstring"),
+            Violation(
+                57, "warning: TODO the name of this method is a little bit confusing"
+            ),
+            Violation(
+                183,
+                "error: Invalid name '' for type argument (should match [a-z_][a-z0-9_]{2,30}$)",
+            ),
         ]
 
         # We're not guaranteed that the violations are returned
         # in any particular order.
-        actual_violations = quality.violations('path/to/file.java')
+        actual_violations = quality.violations("path/to/file.java")
         self.assertEqual(len(actual_violations), len(expected_violations))
         for expected in expected_violations:
             self.assertIn(expected, actual_violations)
 
 
 class FindbugsQualityReporterTest(unittest.TestCase):
-
     def setUp(self):
         _patch_so_all_files_exist()
         # Paths generated by git_path are always the given argument
-        _git_path_mock = patch('diff_cover.violationsreporters.java_violations_reporter.GitPathTool').start()
+        _git_path_mock = patch(
+            "diff_cover.violationsreporters.java_violations_reporter.GitPathTool"
+        ).start()
         _git_path_mock.relative_path = lambda path: path
         _git_path_mock.absolute_path = lambda path: path
 
@@ -257,12 +302,12 @@ class FindbugsQualityReporterTest(unittest.TestCase):
         quality = QualityReporter(FindbugsXmlDriver())
 
         # Expect that we get no results
-        result = quality.violations('')
+        result = quality.violations("")
         self.assertEqual(result, [])
 
     def test_no_java_file(self):
         quality = QualityReporter(FindbugsXmlDriver())
-        file_paths = ['file1.coffee', 'subdir/file2.js']
+        file_paths = ["file1.coffee", "subdir/file2.js"]
         # Expect that we get no results because no Java files
         for path in file_paths:
             result = quality.violations(path)
@@ -272,7 +317,9 @@ class FindbugsQualityReporterTest(unittest.TestCase):
         # When the user provides us with a pre-generated findbugs report
         # then use that instead of calling findbugs directly.
         findbugs_reports = [
-            BytesIO(dedent("""
+            BytesIO(
+                dedent(
+                    """
                 <?xml version="1.0" encoding="UTF-8"?>
                 <BugCollection sequence="0" release="" analysisTimestamp="1512755361404" version="3.0.1" timestamp="1512755226000">
                     <BugInstance instanceOccurrenceNum="0" instanceHash="1967bf8c4d25c6b964f30356014aa9fb" rank="20" abbrev="Dm" category="I18N" priority="3" type="DM_CONVERT_CASE" instanceOccurrenceMax="0">
@@ -296,9 +343,14 @@ class FindbugsQualityReporterTest(unittest.TestCase):
                         </SourceLine>
                     </BugInstance>
                 </BugCollection>
-            """).strip().encode('utf-8')),
-
-            BytesIO(dedent("""
+            """
+                )
+                .strip()
+                .encode("utf-8")
+            ),
+            BytesIO(
+                dedent(
+                    """
                 <?xml version="1.0" encoding="UTF-8"?>
                 <BugCollection sequence="0" release="" analysisTimestamp="1512755361404" version="3.0.1" timestamp="1512755226000">
                     <BugInstance instanceOccurrenceNum="0" instanceHash="1967bf8c4d25c6b964f30356014aa9fb" rank="20" abbrev="Dm" category="I18N" priority="3" type="DM_CONVERT_CASE" instanceOccurrenceMax="0">
@@ -322,10 +374,15 @@ class FindbugsQualityReporterTest(unittest.TestCase):
                         </SourceLine>
                     </BugInstance>
                 </BugCollection>
-            """).strip().encode('utf-8')),
-
+            """
+                )
+                .strip()
+                .encode("utf-8")
+            ),
             # this is a violation which is not bounded to a specific line. We'll skip those
-            BytesIO(dedent("""
+            BytesIO(
+                dedent(
+                    """
                 <?xml version="1.0" encoding="UTF-8"?>
                 <BugCollection sequence="0" release="" analysisTimestamp="1512755361404" version="3.0.1" timestamp="1512755226000">
                     <BugInstance instanceOccurrenceNum="0" instanceHash="2820338ec68e2e75a81848c95d31167f" rank="19" abbrev="Se" category="BAD_PRACTICE" priority="3" type="SE_BAD_FIELD" instanceOccurrenceMax="0">
@@ -336,7 +393,11 @@ class FindbugsQualityReporterTest(unittest.TestCase):
                         </SourceLine>
                     </BugInstance>
                 </BugCollection>
-            """).strip().encode('utf-8'))
+            """
+                )
+                .strip()
+                .encode("utf-8")
+            ),
         ]
 
         # Generate the violation report
@@ -344,24 +405,31 @@ class FindbugsQualityReporterTest(unittest.TestCase):
 
         # Expect that we get the right violations
         expected_violations = [
-            Violation(97, 'I18N: Consider using Locale parameterized version of invoked method'),
-            Violation(183, 'I18N: Consider using Locale parameterized version of invoked method')
+            Violation(
+                97,
+                "I18N: Consider using Locale parameterized version of invoked method",
+            ),
+            Violation(
+                183,
+                "I18N: Consider using Locale parameterized version of invoked method",
+            ),
         ]
 
         # We're not guaranteed that the violations are returned
         # in any particular order.
-        actual_violations = quality.violations('path/to/file.java')
+        actual_violations = quality.violations("path/to/file.java")
         self.assertEqual(len(actual_violations), len(expected_violations))
         for expected in expected_violations:
             self.assertIn(expected, actual_violations)
 
 
 class PmdXmlQualityReporterTest(unittest.TestCase):
-
     def setUp(self):
         _patch_so_all_files_exist()
         # Paths generated by git_path are always the given argument
-        _git_path_mock = patch('diff_cover.violationsreporters.java_violations_reporter.GitPathTool').start()
+        _git_path_mock = patch(
+            "diff_cover.violationsreporters.java_violations_reporter.GitPathTool"
+        ).start()
         _git_path_mock.relative_path = lambda path: path
         _git_path_mock.absolute_path = lambda path: path
 
@@ -375,12 +443,12 @@ class PmdXmlQualityReporterTest(unittest.TestCase):
         quality = QualityReporter(PmdXmlDriver())
 
         # Expect that we get no results
-        result = quality.violations('')
+        result = quality.violations("")
         self.assertEqual(result, [])
 
     def test_no_java_file(self):
         quality = QualityReporter(PmdXmlDriver())
-        file_paths = ['file1.coffee', 'subdir/file2.js']
+        file_paths = ["file1.coffee", "subdir/file2.js"]
         # Expect that we get no results because no Java files
         for path in file_paths:
             result = quality.violations(path)
@@ -390,7 +458,9 @@ class PmdXmlQualityReporterTest(unittest.TestCase):
         # When the user provides us with a pre-generated findbugs report
         # then use that instead of calling findbugs directly.
         pmd_reports = [
-            BytesIO(dedent("""
+            BytesIO(
+                dedent(
+                    """
             <?xml version="1.0" encoding="UTF-8"?>
             <pmd version="5.6.1" timestamp="2019-06-24T15:47:13.429">
             <file name="path/to/file.java">
@@ -404,7 +474,11 @@ class PmdXmlQualityReporterTest(unittest.TestCase):
             </violation>
             </file>
             </pmd>
-            """).strip().encode('utf-8'))
+            """
+                )
+                .strip()
+                .encode("utf-8")
+            )
         ]
 
         pmd_xml_driver = PmdXmlDriver()
@@ -416,13 +490,16 @@ class PmdXmlQualityReporterTest(unittest.TestCase):
 
         # Expect that we get the right violations
         expected_violations = [
-            Violation(21, 'ClassMustHaveAuthorRule: must have @author comment'),
-            Violation(10, 'AbstractMethodOrInterfaceMethodMustUseJavadocRule: interface method must include javadoc comment')
+            Violation(21, "ClassMustHaveAuthorRule: must have @author comment"),
+            Violation(
+                10,
+                "AbstractMethodOrInterfaceMethodMustUseJavadocRule: interface method must include javadoc comment",
+            ),
         ]
 
         # We're not guaranteed that the violations are returned
         # in any particular order.
-        actual_violations = quality.violations('path/to/file.java')
+        actual_violations = quality.violations("path/to/file.java")
         self.assertEqual(len(actual_violations), len(expected_violations))
         for expected in expected_violations:
             self.assertIn(expected, actual_violations)
